@@ -35,7 +35,10 @@ create table numeric_types
 	demical_2_type decimal(10,5) null,
 	float_type float null,
 	double_type double null,
-	bit_type bit null
+	bit_type bit null,
+	unsigned_int_type int unsigned null,
+	unsigned_tinyint_type tinyint unsigned null,
+	unsigned_bigint_type bigint unsigned null
 );
 
 create table if not exists date_types
@@ -60,3 +63,13 @@ create table if not exists string_types
 	varchar_type varchar(44) null
 );
 
+create table if not exists no_auto_increment
+(
+	id bigint not null
+		primary key,
+	text longtext null,
+	address_id int null,
+	constraint table_name_address_id_fk
+		foreign key (address_id) references address (id)
+);
+
